summaryrefslogtreecommitdiffstats
path: root/korn/subjectsdlg.h
diff options
context:
space:
mode:
Diffstat (limited to 'korn/subjectsdlg.h')
-rw-r--r--korn/subjectsdlg.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/korn/subjectsdlg.h b/korn/subjectsdlg.h
index e7c032c2a..8201e8e6d 100644
--- a/korn/subjectsdlg.h
+++ b/korn/subjectsdlg.h
@@ -24,6 +24,7 @@ template< class T > class TQPtrList;
class KornSubjectsDlg: public KDialogBase
{
Q_OBJECT
+ TQ_OBJECT
/**
* SubjectListViewItem is a helper class representing one line in the list view.
@@ -35,11 +36,11 @@ class KornSubjectsDlg: public KDialogBase
public:
/**
* SubjectListViewItem Constructor
* @param parent list view
* @param item KornMailSubject this item should represent. It is NOT deleted
* if SubjectListViewItem is deleted.
*/
- SubjectListViewItem( TQListView *parent, KornMailSubject * item);
+ SubjectListViewItem( TQListView *tqparent, KornMailSubject * item);
/**
* SubjectListViewItem Destructor
@@ -103,9 +104,9 @@ class KornSubjectsDlg: public KDialogBase
public:
/**
* KornSubjectsDlg Constructor
* @param parent parent widget
*/
- KornSubjectsDlg( TQWidget *parent=0 );
+ KornSubjectsDlg( TQWidget *tqparent=0 );
/**
* This functions clears all available KMailDrop's.
@@ -35,11 +36,11 @@ class KornSubjectsDlg: public KDialogBase
/**
* SubjectListViewItem Constructor
- * @param parent list view
+ * @param tqparent list view
* @param item KornMailSubject this item should represent. It is NOT deleted
* if SubjectListViewItem is deleted.
@@ -103,9 +104,9 @@ class KornSubjectsDlg: public KDialogBase
/**
* KornSubjectsDlg Constructor
- * @param parent parent widget
+ * @param tqparent tqparent widget
*/